---
title: <span class="badge builder"></span> AzureResourceGraphQuery
---
# <span class="badge builder"></span> AzureResourceGraphQuery

## Constructor

```python
AzureResourceGraphQuery()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> azuremonitor.AzureResourceGraphQuery
```

### <span class="badge object-method"></span> query

Azure Resource Graph KQL query to be executed.

```python
def query(query: str) -> typing.Self
```

### <span class="badge object-method"></span> result_format

Specifies the format results should be returned as. Defaults to table.

```python
def result_format(result_format: str) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [AzureResourceGraphQuery](./object-AzureResourceGraphQuery.md)
